.. _spkg_libsemigroups:

libsemigroups: Library for semigroups and monoids
=================================================

Description
-----------

C++ library for semigroups and monoids; used in GAP's package
Semigroups.

License
-------

GPL-3.0


Upstream Contact
----------------

http://james-d-mitchell.github.io/libsemigroups
https://github.com/james-d-mitchell/libsemigroups


Type
----

optional


Dependencies
------------



Version Information
-------------------

package-version.txt::

    2.7.4

See https://repology.org/project/libsemigroups/versions

Installation commands
---------------------

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i libsemigroups

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install libsemigroups

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install libsemigroups libsemigroups-devel

.. tab:: FreeBSD:

   .. CODE-BLOCK:: bash

       $ sudo pkg install math/libsemigroups

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install pkgconfig\(libsemigroups\)


If the system package is installed, ``./configure`` will check if it can be used.
